@@ -11,16 +11,14 @@ from nonebot import logger
 
 from ...config import pconfig
 from ...download import DOWNLOADER
-from ...exception import DownloadException, ParseException
+from ...exception import DownloadException, DurationLimitException, ParseException
 from ..base import BaseParser
 from ..cookie import ck2dict
 from ..data import (
-    Author,
     GraphicsContent,
     ImageContent,
     MediaContent,
     Platform,
-    VideoContent,
 )
 
 
@@ -124,12 +122,6 @@ class BilibiliParser(BaseParser):
         else:
             ai_summary: str = "哔哩哔哩 cookie 未配置或失效, 无法使用 AI 总结"
 
-        # 额外信息
-        extra = {"info": f"简介：{video_info.desc}\n\n{ai_summary}"}
-
-        # 下载封面
-        cover_path = DOWNLOADER.download_img(cover_url, ext_headers=self.headers) if cover_url else None
-
         url = f"https://bilibili.com/{video_info.bvid}" + (f"?p={page_idx + 1}" if page_idx > 0 else "")
 
         # 视频下载 task
@@ -137,9 +129,9 @@ class BilibiliParser(BaseParser):
             output_path = pconfig.cache_dir / f"{video_info.bvid}-{page_num}.mp4"
             if output_path.exists():
                 return output_path
-            v_url, a_url = await self.parse_video_download_url(video=video, page_index=page_idx)
+            v_url, a_url = await self.get_download_urls(video=video, page_index=page_idx)
             if duration > pconfig.duration_maximum:
-                raise DownloadException("视频时长超过最大限制")
+                raise DurationLimitException
             if a_url is not None:
                 return await DOWNLOADER.download_av_and_merge(
                     v_url, a_url, output_path=output_path, ext_headers=self.headers
@@ -150,12 +142,13 @@ class BilibiliParser(BaseParser):
         video_task = asyncio.create_task(download_video())
 
         return self.result(
-            title=title,
             url=url,
-            extra=extra,
+            title=title,
             timestamp=timestamp,
-            author=Author(name=video_info.owner.name, avatar=DOWNLOADER.download_img(video_info.owner.face)),
-            contents=[VideoContent(video_task, cover_path, duration)],
+            text=f"简介：{video_info.desc}",
+            author=self.create_author(video_info.owner.name, video_info.owner.face),
+            contents=[self.create_video_content(video_task, cover_url, duration)],
+            extra={"info": ai_summary},
         )
 
     async def parse_others(self, url: str):
@@ -415,7 +408,7 @@ class BilibiliParser(BaseParser):
         else:
             raise ParseException("avid 和 bvid 至少指定一项")
 
-    async def parse_video_download_url(
+    async def get_download_urls(
         self,
         *,
         video: Video | None = None,
@@ -451,8 +444,9 @@ class BilibiliParser(BaseParser):
         )
         video_stream = streams[0]
         if not isinstance(video_stream, VideoStreamDownloadURL):
-            raise ParseException("未找到可下载的视频流")
+            raise DownloadException("未找到可下载的视频流")
         logger.debug(f"视频流质量: {video_stream.video_quality.name}, 编码: {video_stream.video_codecs}")
+
         audio_stream = streams[1]
         if not isinstance(audio_stream, AudioStreamDownloadURL):
             return video_stream.url, None
