@@ -4,8 +4,8 @@ from itertools import chain
 from pathlib import Path
 from typing import Any, ClassVar
 
-from ..exception import MultiException, ParseException
-from ..helper import Segment, UniHelper, UniMessage
+from ..exception import DownloadException, DownloadLimitException, ZeroSizeException
+from ..helper import ForwardNodeInner, UniHelper, UniMessage
 from ..parsers import ParseResult
 from ..parsers.data import AudioContent, DynamicContent, GraphicsContent, ImageContent, VideoContent
 
@@ -39,15 +39,19 @@ class BaseRenderer(ABC):
         Returns:
             AsyncGenerator[UniMessage[Any], None]: 消息生成器
         """
-        raises: list[ParseException] = []
-        forwardable_segs: list[str | Segment | UniMessage] = []
+        failed_count = 0
+        forwardable_segs: list[ForwardNodeInner] = []
+
         for cont in chain(result.contents, result.repost.contents if result.repost else ()):
             try:
                 path = await cont.get_path()
-            except ParseException as e:
-                forwardable_segs.append(e.message)
-                raises.append(e)
-                # 继续渲染其他内容
+            # 继续渲染其他内容, 类似之前 gather (return_exceptions=True) 的处理
+            except (DownloadLimitException, ZeroSizeException):
+                # 预期异常，不抛出
+                # yield UniMessage(e.message)
+                continue
+            except DownloadException:
+                failed_count += 1
                 continue
 
             match cont:
@@ -63,11 +67,10 @@ class BaseRenderer(ABC):
                     forwardable_segs.append(text + UniHelper.img_seg(path))
 
         if forwardable_segs:
-            if all(isinstance(seg, str) for seg in forwardable_segs):
-                yield UniMessage(forwardable_segs)
-            else:
-                forward_msg = UniHelper.construct_forward_message(forwardable_segs)
-                yield UniMessage(forward_msg)
+            forward_msg = UniHelper.construct_forward_message(forwardable_segs)
+            yield UniMessage(forward_msg)
 
-        if raises:
-            raise MultiException(raises)
+        if failed_count > 0:
+            message = f"{failed_count} 项媒体下载失败"
+            yield UniMessage(message)
+            raise DownloadException(message)
